# EIDA Consistency Report: `NIEP`

- Seed: `330643`
- Time: `2025-09-08T17:12:07.949196+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `15`
- Inconsistent: `5`
- Score: **75.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `5`

## Dataselect Response Types
- **NoTrace**: `5`
- **SingleTrace**: `15`

---

## Detailed Results
### `BS.KUBB..HHZ`
- Window: `2014-03-27T01:37:28 → 2014-03-27T01:47:28`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `RO.TSMN..SHN`
- Window: `2014-02-11T07:30:14 → 2014-02-11T07:40:14`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `RO.TSCT..VEP`
- Window: `2024-02-29T14:19:56 → 2024-02-29T14:29:56`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `RO.HUMR..BHE`
- Window: `2016-08-31T22:23:07 → 2016-08-31T22:33:07`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `Y8.PL24A..HHZ`
- Window: `2022-09-17T01:28:53 → 2022-09-17T01:38:53`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Y8.PL07A..HHE`
- Window: `2022-11-11T07:37:04 → 2022-11-11T07:47:04`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BS.KKB..HHN`
- Window: `2022-11-22T06:57:38 → 2022-11-22T07:07:38`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `RO.COPA..HHZ`
- Window: `2018-10-27T11:31:11 → 2018-10-27T11:41:11`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `RO.MHISU..HNZ`
- Window: `2018-11-07T22:27:16 → 2018-11-07T22:37:16`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `RO.STFAR..HHE`
- Window: `2023-11-05T03:41:52 → 2023-11-05T03:51:52`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Y8.RO02A.00.HHZ`
- Window: `2022-10-25T09:40:46 → 2022-10-25T09:50:46`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Y8.BG01A.00.HHZ`
- Window: `2022-06-28T23:38:29 → 2022-06-28T23:48:29`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Y8.PL11A..HHN`
- Window: `2022-12-19T22:30:26 → 2022-12-19T22:40:26`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `UD.MI29..BHZ`
- Window: `2019-06-27T04:57:44 → 2019-06-27T05:07:44`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `RO.STFAR..HNN`
- Window: `2024-12-31T18:02:58 → 2024-12-31T18:12:58`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `Y8.PL13A..HHE`
- Window: `2022-11-03T07:41:56 → 2022-11-03T07:51:56`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `RO.RMVG..EHZ`
- Window: `2020-12-19T00:39:04 → 2020-12-19T00:49:04`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `RO.BANR..BHN`
- Window: `2023-07-21T06:24:44 → 2023-07-21T06:34:44`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Y8.PL21A..HHZ`
- Window: `2022-12-10T13:12:52 → 2022-12-10T13:22:52`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Y8.RO03A.00.HHZ`
- Window: `2022-10-16T09:44:43 → 2022-10-16T09:54:43`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`
